datablock ExplosionData(blackopsfragExplosion)
{
   lifeTimeMS = 150;
   shakeCamera = false;
   impulseRadius = 25;
   impulseForce =  5000;
   damageRadius = 25;
   radiusDamage = 250;
   lightStartRadius = 0;
   lightEndRadius = 0;
   explosionScale = "1 1 1";
   soundProfile = "RocketExplodeSound";
};

datablock ProjectileData(blackopsfragProjectile)
{
   projectileShapeName = "./fragProjectile.dts";
   directDamage        = 0;
   impactImpulse      = 0;
   verticalImpulse    = 0;
   brickExplosionRadius = 0;
   brickExplosionImpact = false; //destroy a brick if we hit it directly?
   brickExplosionForce  = 0;             
   brickExplosionMaxVolume = 0;          //max volume of bricks that we can destroy
   brickExplosionMaxVolumeFloating = 0;  //max volume of bricks that we can destroy if they aren't connected to the ground (should always be >= brickExplosionMaxVolume)
   explosion           = blackopsfragExplosion;
   muzzleVelocity      = 30;
   velInheritFactor    = 0;
   explodeOnDeath = true;
   armingDelay         = 5000; 
   lifetime            = 5050;
   fadeDelay           = 6000;
   bounceElasticity    = 0.4;
   bounceFriction      = 0.3;
   isBallistic         = true;
   gravityMod = 1.0;
   hasLight = false;
};

datablock ItemData(blackopsfragItem)
{
	category = "Weapon";
	className = "Weapon";
	shapeFile = "./frag.dts";
	mass = 1;
	density = 0.2;
	elasticity = 0.2;
	friction = 0.6;
	emap = true;
	uiName = "Frag Grenade (bomw)";
	image = blackopsfragImage;
	canDrop = true;
	iconName = "./fragicon";
};

datablock ShapeBaseImageData(blackopsfragImage)
{
   // Basic Item properties
   shapeFile = "./frag.dts";
   emap = true;

   // Specify mount point & offset for 3rd person, and eye offset
   // for first person rendering.
   mountPoint = 0;
   offset = "0 0 0";
   //eyeOffset = "0.1 0.2 -0.55";

   // When firing from a point offset from the eye, muzzle correction
   // will adjust the muzzle vector to point to the eye LOS point.
   // Since this weapon doesn't actually fire from the muzzle point,
   // we need to turn this off.  
   correctMuzzleVector = true;

   // Add the WeaponImage namespace as a parent, WeaponImage namespace
   // provides some hooks into the inventory system.
   className = "WeaponImage";

   // Projectile && Ammo.
   item = blackopsfragItem;
   ammo = " ";
   projectile = blackopsfragProjectile;
   projectileType = Projectile;

   //melee particles shoot from eye node for consistancy
   melee = false;
   //raise your arm up or not
   armReady = true;

   // Images have a state system which controls how the animations
   // are run, which sounds are played, script callbacks, etc. This
   // state system is downloaded to the client so that clients can
   // predict state changes and animate accordingly.  The following
   // system supports basic ready->fire->reload transitions as
   // well as a no-ammo->dryfire idle state.

   // Initial start up state
	stateName[0]			= "Activate";
	stateTimeoutValue[0]		= 0.1;
	stateTransitionOnTimeout[0]	= "Ready";
	stateSequence[0]		= "ready";
	stateSound[0]					= weaponSwitchSound;

	stateName[1]			= "Ready";
	stateTransitionOnTriggerDown[1]	= "Pindrop";
	stateAllowImageChange[1]	= true;

	stateName[2]			= "Pindrop";
	stateTransitionOnTimeout[2]	= "Pinfallen";
	stateAllowImageChange[2]	= false;
	stateTimeoutValue[2]		= 0.2;
	stateSound[2]			= blackopsFireSound;
	stateSequence[2]                = "Pinpull";

	stateName[3]			= "Pinfallen";
	stateTransitionOnTriggerDown[3]	= "Charge";
	stateAllowImageChange[3]	= false;
	
	stateName[4]                    = "Charge";
	stateTransitionOnTimeout[4]	= "Armed";
	stateTimeoutValue[4]            = 0.7;
	stateWaitForTimeout[4]		= false;
	stateTransitionOnTriggerUp[4]	= "AbortCharge";
	stateScript[4]                  = "onCharge";
	stateAllowImageChange[4]        = false;
	
	stateName[5]			= "AbortCharge";
	stateTransitionOnTimeout[5]	= "Pinfallen";
	stateTimeoutValue[5]		= 0.3;
	stateWaitForTimeout[5]		= true;
	stateScript[5]			= "onAbortCharge";
	stateAllowImageChange[5]	= false;

	stateName[6]			= "Armed";
	stateTransitionOnTriggerUp[6]	= "Fire";
	stateAllowImageChange[6]	= false;

	stateName[7]			= "Fire";
	stateTransitionOnTimeout[7]	= "Done";
	stateTimeoutValue[7]		= 0.5;
	stateFire[7]			= true;
	stateSequence[7]		= "fire";
	stateScript[7]			= "onFire";
	stateWaitForTimeout[7]		= true;
	stateAllowImageChange[7]	= false;

	stateName[8]					= "Done";
	stateScript[8]					= "onDone";

};


function blackopsfragImage::onCharge(%this, %obj, %slot)
{
	%obj.playthread(2, spearReady);
	%obj.lastfrag = %obj.currTool;
}

function blackopsfragImage::onAbortCharge(%this, %obj, %slot)
{
	%obj.playthread(2, root);
}

function blackopsfragProjectile::onCollision(%this,%obj,%col,%fade,%pos,%normal)
{
	if(!%obj.noclick)
		serverPlay3D(blackopsBounceSound,%obj.getTransform());
}

function blackopsfragImage::onFire(%this, %obj, %slot)
{
	Parent::OnFire(%this, %obj, %slot);
	%obj.tool[%obj.lastfrag] = 0;
	messageClient(%obj.client,'MsgItemPickup','',%obj.lastfrag,0);
	serverCmdUnUseTool(%obj.client);
}

function blackopsfragprojectile::onExplode(%this,%obj)
{
	%obj.noclick = true;
	parent::onExplode(%this, %obj);
}
